@@ -1,16 +1,20 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
+
 from functools import wraps
 
 from PyNVTX_backend import *
+from .singleton     import Singleton
+from .registry      import Registry
 
 
 major_version   = 0;
-minor_version   = 1;
-release_version = 3;
+minor_version   = 2;
+release_version = 0;
 
 NVTX_IDENTIFIER = "NVTX"
+REGISTRY = Registry()
 
 
 
@@ -44,13 +48,16 @@ def mark_all_methods(cls):
         return
 
     for attr in cls.__dict__:
-        if callable(getattr(cls, attr)):
-            dec = mark(f"{cls}.{attr}")
-            setattr(cls, attr, dec(getattr(cls, attr)))
+        if REGISTRY.skip(cls, attr):
+            continue
 
-    setattr(cls, dec_id_str(NVTX_IDENTIFIER), True)
+        if callable(cls.__dict__[attr]):
+            dec = mark(f"{cls}.{attr}")
+            type.__setattr__(cls, attr, dec(cls.__dict__[attr]))
+
+    type.__setattr__(cls, dec_id_str(NVTX_IDENTIFIER), True)
 
     for base in cls.__bases__:
         if base == object:
            continue
-        mark_all_methods(decorator, base)
+        mark_all_methods(base)
